@@ -243,8 +243,6 @@ def get_feature_summary_and_dropped_feature_types(
             summary["RawFeatureName"]
         )
 
-    print(feature_type_to_feature_name_dict)
-    print(list(FeatureType.DROP_SET))
     return feature_type_to_feature_name_dict, list(FeatureType.DROP_SET)
 
 
